from setuptools import setup

setup(
    name="invisibles-py",
    version="0.0.1",
    description="Package name reserved for future use",
    long_description="This package name is reserved for future development.",
    long_description_content_type="text/plain",
    author="Gor Arakelyan",
    author_email="arakelyangor10@gmail.com",
    url="https://github.com/gorarakelyan/invisibles-py",
    py_modules=[],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
    ],
    python_requires=">=3.6",
)
